@@ -379,6 +379,14 @@ struct kuictx {
 	 * The file descriptor to read from.
 	 */
 	int fd;
+
+	/**
+	 * The literal value of the last map completed.
+	 * This is so that when the client recieves a CGDB_KEY_PPAGE, they can map
+	 * it back to the ascii char's that made up the key, which would be 
+	 * something like "\027\80\81"
+	 */
+	char *last_maps_raw_data;
 };
 
 static int kui_ms_destroy_int_callback ( void *param ) {
@@ -409,6 +417,7 @@ struct kuictx *kui_create(
 	kctx->state_data = state_data;
 	kctx->kui_map_set_list = std_list_create ( NULL );
 	kctx->ms = ms;
+	kctx->last_maps_raw_data = NULL;
 
 	if ( !kctx->kui_map_set_list ) {
 		kui_destroy ( kctx );
@@ -849,6 +858,7 @@ static int kui_update_buffer (
 
 		/* Add the value onto the buffer */
 		length = intlen ( the_map_found->literal_value );
+
 		for ( i = length-1; i >= 0; --i ) {
 			int *val = malloc ( sizeof ( int ) );
 			if ( !val )
@@ -861,6 +871,32 @@ static int kui_update_buffer (
 		}
 	}
 
+	/* This block is only here to set kctx->last_maps_raw_data.
+	 * Later, a client of the KUI, may want to know what was actually typed to 
+	 * get CGDB_KEY_*
+	 * If the map was found, save the literal_key. Otherwise, set it to NULL. 
+	 */
+	if ( map_was_found ) {
+		int length;
+
+		if ( kctx->last_maps_raw_data ) {
+			free ( kctx->last_maps_raw_data );
+			kctx->last_maps_raw_data = NULL;
+		}
+
+		length = intlen ( the_map_found->literal_key );
+
+		kctx->last_maps_raw_data = (char*)malloc ( sizeof(char)*(length+1) );
+
+		if ( !kctx->last_maps_raw_data )
+			return -1;
+
+		/* Copy null terminated char also */
+		for ( i = 0; i <= length; ++i )
+			kctx->last_maps_raw_data[i] = the_map_found->literal_key[i];
+
+	} 
+
 	return 0;
 }
 
@@ -967,6 +1003,12 @@ int kui_getkey ( struct kuictx *kctx ) {
 	int map_found; 
 	int key;
 
+	/* Set the last_maps raw data value to NULL */
+	if ( kctx->last_maps_raw_data ) {
+		free ( kctx->last_maps_raw_data );
+		kctx->last_maps_raw_data = NULL;
+	}
+
 	/* If a map was found, restart the algorithm. */
 	do {
 		key = kui_findkey ( kctx, &map_found );
@@ -994,6 +1036,21 @@ int kui_cangetkey ( struct kuictx *kctx ) {
 	return 0;
 }
 
+const char *kui_get_raw_data ( struct kuictx *kctx ) {
+	if ( !kctx )
+		return NULL;
+
+	return kctx->last_maps_raw_data;
+}
+
+int kui_set_blocking_ms ( struct kuictx *kctx, unsigned long msec ) {
+	if ( !kctx )
+		return -1;
+
+	kctx->ms = msec;
+	return 0;
+}
+
 /* }}} */
 
 /* struct kui_manager {{{ */
@@ -1148,4 +1205,19 @@ int kui_manager_getkey ( struct kui_manager *kuim ) {
 
 }
 
+const char *kui_manager_get_raw_data ( struct kui_manager *kuim ) {
+	if (!kuim)
+		return NULL;
+	return kui_get_raw_data ( kuim->terminal_keys );
+}
+
+int kui_manager_set_terminal_escape_sequence_timeout ( 
+		struct kui_manager *kuim, 
+		unsigned int msec ) {
+	if ( !kuim )
+		return -1;
+
+	return kui_set_blocking_ms ( kuim->terminal_keys, msec );
+}
+
 /* }}} */
