@@ -61,7 +61,8 @@
 #include "sources.h"
 #include "tgdb.h"
 #include "helptext.h"
-#include "input.h"
+#include "kui.h"
+#include "kui_term.h"
 #include "fs_util.h"
 #include "cgdbrc.h"
 #include "io.h"
@@ -83,7 +84,7 @@ static int tgdb_readline_fd = -1; /* tgdb returns the 'at prompt' data */
 
 static char *debugger_path = NULL;  /* Path to debugger to use */
 
-struct input *input = NULL;         /* Initialize the input package */
+struct kui_manager *kui_ctx = NULL; /* The key input package */
 
 int resize_pipe[2] = { -1, -1 };
 
@@ -136,15 +137,21 @@ static void parse_long_options(int *argc, char ***argv) {
 #ifdef HAVE_GETOPT_H
     static struct option long_options[] = {
         { "version", 0, 0, 0 },
-        { "help", 0, 0, 0 }
+        { "help", 0, 0, 0 },
+		{ 0, 0, 0, 0 }
     };
-
-    opterr = 0;
-    while ((c = getopt_long(*argc, *argv, args, long_options, &option_index)) != EOF) {
-#else
-    opterr = 0;
-    while ((c = getopt(*argc, *argv, args)) != EOF) {
 #endif
+
+	while ( 1 ) {
+    	opterr = 0;
+#ifdef HAVE_GETOPT_H
+        c = getopt_long(*argc, *argv, args, long_options, &option_index);
+#else
+        c = getopt(*argc, *argv, args);
+#endif
+   		if ( c == -1 )
+			break;
+
         switch (c) {
             case 0:
                 switch ( option_index ) {
@@ -215,8 +222,9 @@ static int create_help_file(void) {
 
    /* Write cgdb version number */
    length = 5 + strlen(VERSION);
-   dashes = (char *)malloc(sizeof(char) * (length));
+   dashes = (char *)malloc(sizeof(char) * (length+1));
    memset(dashes, '-', length);
+   dashes[length] = 0;
    fprintf(fd, "CGDB %s\n%s\n\n", VERSION, dashes);
    free(dashes);
 
@@ -259,23 +267,23 @@ static void send_key(int focus, int key) {
 static int user_input(void) {
     static int key, val;
     
-    key = input_getkey(input);
+	key = kui_manager_getkey ( kui_ctx );
 
     /* Process the key */
     switch ( ( val = if_input(key)) ) {
         case 1:
         case 2:
-            if ( key >= CGDB_KEY_ESC && key < CGDB_KEY_ERROR ) {
-                    char *seqbuf = input_get_last_seq(input);
+            if ( kui_term_is_cgdb_key ( key ) ) {
+				char *seqbuf = (char*)kui_manager_get_raw_data( kui_ctx );
 
-                    if ( seqbuf == NULL ) {
-                        err_msg("%s:%d input_get_last_seq error\n", __FILE__, __LINE__);
-                        return -1;
-                    } else {
-                        int length = strlen(seqbuf), i;
-                        for ( i = 0; i < length; i++ )
-                            send_key(val, seqbuf[i]);
-                    }
+				if ( seqbuf == NULL ) {
+					err_msg("%s:%d input_get_last_seq error\n", __FILE__, __LINE__);
+					return -1;
+				} else {
+					int length = strlen(seqbuf), i;
+					for ( i = 0; i < length; i++ )
+						send_key(val, seqbuf[i]);
+				}
             } else
                 send_key(val, key);
     
@@ -630,7 +638,8 @@ int main(int argc, char *argv[]) {
         exit(-1);
     }
 
-    if ( (input = input_init(STDIN_FILENO) ) == NULL )
+	kui_ctx = kui_manager_create ( STDIN_FILENO );
+	if ( !kui_ctx  )
         err_quit("%s: Unable to initialize input library\n", my_name); 
 
     /* Initialize the display */
@@ -668,6 +677,6 @@ int main(int argc, char *argv[]) {
     return 0;
 }
 
-void cgdb_set_esc_sequence_timeout ( int msec ) {
-	input_set_escape_sequence_timeout_value ( input, msec );
+int cgdb_set_esc_sequence_timeout ( int msec ) {
+	return kui_manager_set_terminal_escape_sequence_timeout ( kui_ctx, msec );
 }
